// Sample dataset with x, y, and size values for bubbles
const dataset = [
  { x: 10, y: 20, size: 5 },
  { x: 30, y: 40, size: 10 },
  { x: 50, y: 10, size: 15 },
  { x: 70, y: 30, size: 8 },
   { x: 40, y: 60, size: 5 },
  { x: 90, y: 10, size: 30 },
  { x: 80, y: 50, size: 15 },
  { x: 60, y: 30, size: 13 },
  // Add more data as needed
];

// Set up chart dimensions
const width = 400;
const height = 300;
const margin = { top: 20, right: 30, bottom: 30, left: 40 };
const chartWidth = width - margin.left - margin.right;
const chartHeight = height - margin.top - margin.bottom;

// Create the SVG element
const svg = d3.select('#chart')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Create the chart group
const chart = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);

// Create x and y scales
const xScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d.x)])
  .range([0, chartWidth]);

const yScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d.y)])
  .range([chartHeight, 0]);

// Create and append the bubbles
chart.selectAll('circle')
  .data(dataset)
  .enter()
  .append('circle')
  .attr('cx', d => xScale(d.x))
  .attr('cy', d => yScale(d.y))
  .attr('r', d => d.size) // Adjust the bubble size based on the 'size' value in the dataset
  .attr('fill', 'steelblue');

// Add x-axis
chart.append('g')
  .attr('transform', `translate(0, ${chartHeight})`)
  .call(d3.axisBottom(xScale));

// Add y-axis
chart.append('g')
  .call(d3.axisLeft(yScale));

// Add x-axis label
svg.append('text')
  .attr('transform', `translate(${width / 2}, ${height - margin.bottom})`)
  .style('text-anchor', 'middle')
  .text('X-axis Label');

// Add y-axis label
svg.append('text')
  .attr('transform', 'rotate(-90)')
  .attr('y', margin.left / 2)
  .attr('x', 0 - height / 2)
  .style('text-anchor', 'middle')
  .text('Y-axis Label');
